summaryrefslogtreecommitdiff
path: root/src/xmenu.c
diff options
context:
space:
mode:
authorPaul Eggert <eggert@cs.ucla.edu>2011-04-29 10:56:27 -0700
committerPaul Eggert <eggert@cs.ucla.edu>2011-04-29 10:56:27 -0700
commitd01a78266d12561b46777a2156914d12d8099c4f (patch)
tree3fa5ec64d44faeca79a6fe89b88362cda723fdff /src/xmenu.c
parent7fd47d5ce2020a22f8db9776e8d1f47891b966dc (diff)
downloademacs-d01a78266d12561b46777a2156914d12d8099c4f.tar.gz
* lisp.h (EMACS_INTPTR): Remove. All uses changed to intptr_t.
(EMACS_UINTPTR): Likewise, with uintptr_t.
Diffstat (limited to 'src/xmenu.c')
-rw-r--r--src/xmenu.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/xmenu.c b/src/xmenu.c
index 54f1fc666ec..35ad42970cf 100644
--- a/src/xmenu.c
+++ b/src/xmenu.c
@@ -1139,9 +1139,9 @@ set_frame_menubar (FRAME_PTR f, int first_time, int deep_p)
wv->help = Qnil;
/* This prevents lwlib from assuming this
menu item is really supposed to be empty. */
/* The EMACS_INTPTR cast avoids a warning.
This value just has to be different from small integers. */
- wv->call_data = (void *) (EMACS_INTPTR) (-1);
+ wv->call_data = (void *) (intptr_t) (-1);
if (prev_wv)
prev_wv->next = wv;
@@ -1878,7 +1878,7 @@ dialog_selection_callback (GtkWidget *widget, gpointer client_data)
{
/* Treat the pointer as an integer. There's no problem
as long as pointers have enough bits to hold small integers. */
- if ((EMACS_INTPTR) client_data != -1)
+ if ((intptr_t) client_data != -1)
menu_item_selection = (Lisp_Object *) client_data;
popup_activated_flag = 0;
@@ -1139,9 +1139,9 @@ set_frame_menubar (FRAME_PTR f, int first_time, int deep_p)
/* This prevents lwlib from assuming this
menu item is really supposed to be empty. */
- /* The EMACS_INTPTR cast avoids a warning.
+ /* The intptr_t cast avoids a warning.
This value just has to be different from small integers. */